#ifndef CAMERAINTERFACE_H
#define CAMERAINTERFACE_H

/*
 * automatically generated with the command line :
 * m-servicefwgen -p com.nokia.maemo.meegotouch.CameraInterface
 */

#include <QObject>

#include <mservicefwbaseif.h>


/**
 * @brief The inteface for using the camera
 * @details 
            This interface is used to launch the camera
 *  application.
            The mode in which the camera will be
 *  after launch can
            be specified, but not enforced.


 *             The signals tell if an image or a video has been

 *             captured or if the camera has been closed without

 *             capturing.

            The camera application can
 *  send the captured signals
            multiple times if the
 *  user captures multiple images
            or videos.
      
 *     
 */
class CameraInterface : public MServiceFwBaseIf
{
Q_OBJECT

public:

    /**
     * @brief Return the possible modes for camera
     * @details This method returns the list of possible
      
     *           modes for lauching the Camera
                application.

     *                 The modes are returned as strings.
     
     *          
     */
    QStringList enumerateModes();

    /**
     * @brief Open camera applicaiton with the mode
     * @details 
                This method opens the Camera application
     *  in the specified mode. The mode
                should be
     *  one
                from the list queried with the enumerateModes
     *  method.

                The Camera is started the same
     *  way as it would be from the Launcher. The
             
     *    user can then proceed
                to capture images
     *  or videos in the selected mode The user can change the

     *                 mode to a different one specified and browse
     *  content captured with the
                camera. The user
     *  can also launch the Gallery from the Camera.
          
     *     
     */
    bool showCamera( const QString &mode );

    /**
     * @brief Open camera application in still mode
     * @details 
                This method opens the Camera application
     *  in the still image capturing
                mode. The Camera
     *  behaves
                the same as started from the Launcher,
     *  so the user can capture still
                images and
     *  videos. The user
                can change the mode to
     *  a different one and browse through captured content.
  
     *             
     */
    bool showCamera();

public:
    /*!
     * @brief Constructs a base interface
     * @param preferredService the preferred service provider. Leave
     * empty if no preferred provider. In most cases, this should be left
     * empty.
     * @param parent Parent object
     */

    CameraInterface( const QString& preferredService = "", QObject* parent = 0 );

    /*!
     * @brief Set the service name
     * @param service Name of the desired service
     */

    void setService(const QString & service);
Q_SIGNALS:

    /**
     * @brief Camera has been closed
     * @details 
                This signal is sent when the camera
     *  application has been closed.
              
     */
    void cameraClosed();

    /**
     * @brief Capturing has been canceled
     * @details 
                This signal is sent when the user
     *  has canceled a capture. The parameter
                is
     *  a string defining the capture mode canceled, most likely
     *  for panorama.

                The mode string is one of
     *  the strings returned from the enumerateModes
          
     *       method.
              
     */
    void captureCanceled(const QString &mode);

    /**
     * @brief Capturing has been completed
     * @details 
               This signal is sent when capturing
     *  the content has been completed. The
               parameters
     *  returned are a string defining the mode in which the content

     *                was captured and a string which contains the
     *  file name of the captured content.

               The mode
     *  string is one of the strings returned from the enumerateModes

     *                method.
              
     */
    void captureCompleted(const QString &mode, const QString &fileName);

    /**
     * @brief User has started capturing
     * @details 
                This signal is sent when the user
     *  has initiated a capture in the camera.
                The
     *  signal parameter is a string specifying which mode has been
     *  used to
                capture the image. The possible
     *  mode strings are the ones returned by
                the
     *  method enumerateModes.
              
     */
    void captureStarted(const QString &mode);
};
#endif

