#ifndef MUSICSUITEINTERFACE_H
#define MUSICSUITEINTERFACE_H

/*
 * automatically generated with the command line :
 * m-servicefwgen -p com.nokia.maemo.meegotouch.MusicSuiteInterface
 */

#include <QObject>

#include <mservicefwbaseif.h>


/**
 * @brief MusicSuite interface for launching Music application and
 *  playing audio content with it
 * @details MusicSuite interface can be used to play local audio
 *  and audio streams and show Ovi store pages
 */
class MusicSuiteInterface : public MServiceFwBaseIf
{
Q_OBJECT

public:

    /**
     * @brief Queries the current media for song name and
     
     *      artist data
     * @details 
          Query for the current media for song
     *  name and artist data. Triggers the
          emit of the
     *  mediaChanged signal with the result of the query as the

     *           signal parameters.
        
     */
    void currentMedia();

    /**
     * @brief Jump to next song on playlist
     */
    void next();

    /**
     * @brief Opens correct Ovi store page in Ovi tab
     * @details Given stringlist parameter contains URI to Ovi Music
     *  store. The link points to e.g. music album page.
     */
    void openOviMusicLink( const QStringList &link );

    /**
     * @brief Pauses the already started playback
     */
    void pausePlayback();

    /**
     * @brief Starts to play given uris
     */
    void play( const QStringList &uriList );

    /**
     * @brief Starts to play given playlists
     */
    void playPlaylist( const QStringList &uriList );

    /**
     * @brief Query the playback state
     * @details 
          Possible values are
          Stopped,
     *  Playing, Paused, Transitioning, Invalid = 100.
        
     */
    int playbackState();

    /**
     * @brief Jump to previous song on playlist
     */
    void previous();

    /**
     * @brief Resume the paused playback
     */
    void resumePlayback();

public:
    /*!
     * @brief Constructs a base interface
     * @param preferredService the preferred service provider. Leave
     * empty if no preferred provider. In most cases, this should be left
     * empty.
     * @param parent Parent object
     */

    MusicSuiteInterface( const QString& preferredService = "", QObject* parent = 0 );

    /*!
     * @brief Set the service name
     * @param service Name of the desired service
     */

    void setService(const QString & service);
Q_SIGNALS:

    /**
     * @brief Emitted when currently playing media changes
     * @details 
          The return parameters in a list are the
     *  content type, 
          the song title and the artist name.

     *         
     */
    void mediaChanged(const QStringList &mediaChanged);

    /**
     * @brief The playback state has changed
     * @details 
          Emitted when the playback state has changed.

     *           Possible values are
          Stopped, Playing,
     *  Paused, Transitioning, Invalid = 100.
        
     */
    void playbackStateChanged(int playbackState);
};
#endif

