#ifndef VIDEOSUITEINTERFACE_H
#define VIDEOSUITEINTERFACE_H

/*
 * automatically generated with the command line :
 * m-servicefwgen -p com.nokia.maemo.meegotouch.VideoSuiteInterface
 */

#include <QObject>

#include <mservicefwbaseif.h>


/**
 * @brief VideoSuite interface offers methods for playing video.
 * @details VideoSuite interface is used to play videos files or
 *  video streams.
 *  Note: Always check that interface is valid
 *  before issuing command to it. If there's no service provider
 *  for the VideoSuiteInterface installed interface will be 0.
 */
class VideoSuiteInterface : public MServiceFwBaseIf
{
Q_OBJECT

public:

    /**
     * @brief Cancels ongoing operation and closes the video player
     *  application.
     */
    void cancel();

    /**
     * @brief Launches the video player application and emits launched
     *  signal when done.
     */
    void launch();
    void launch( const QString &_taskTitle );

    /**
     * @brief Launches the video player application to playback
     *  with given uris and emits launched signal when done. 
 
     *      @param uriList List of video urns or uris. e.g. "urn:uuid:123-123-123"
     *  or "file:///home/user/video.avi".
     */
    void launch( const QStringList &uriList );
    void launch( const QStringList &uriList, const QString &_taskTitle );

    /**
     * @brief Starts video playback of given MaFW playlist. Emits
     *  playbackStarted when playback command is executed. 
   
     *    @param index Index of the video in playlist. 
      *
     *  @param playlistName Name of the Mafw-playlist. Playlist
     *  must be published before calling this method.
     */
    void play( uint index, const QString &playlistName );
    void play( uint index, const QString &playlistName, const QString &_taskTitle );

    /**
     * @brief Starts video playback of given videos. Emits playbackStarted
     *  when playback command is executed. 
      * @param uriList
     *  List of video urns or uris. e.g. "urn:uuid:123-123-123"
     *  or "urn:uuid:123-123-123".
     */
    void play( const QStringList &uriList );
    void play( const QStringList &uriList, const QString &_taskTitle );

public:
    /*!
     * @brief Constructs a base interface
     * @param preferredService the preferred service provider. Leave
     * empty if no preferred provider. In most cases, this should be left
     * empty.
     * @param parent Parent object
     */

    VideoSuiteInterface( const QString& preferredService = "", QObject* parent = 0 );

    /*!
     * @brief Set the service name
     * @param service Name of the desired service
     */

    void setService(const QString & service);
Q_SIGNALS:

    /**
     * @brief Emitted when video player application is started and
     *  play slot call is finished.
     */
    void launched();

    /**
     * @brief Emitted when video player application is started and
     *  launch slot call is finished.
     */
    void playbackStarted();
};
#endif

